==> centreon-web-24.04.25.tar.gz: centreon-web-24.04.25/tests/e2e/fixtures/shared/constants/pages.ts <==
export const PAGES = {
  configuration: {
    login: '/centreon/login',
    install: '/centreon/install/install.php',
    aclAccessGroupsLegacy: '/centreon/main.php?p=50203',
    aclActionsAccessLegacy: '/centreon/main.php?p=50204',
    aclMenusAccessLegacy: '/centreon/main.php?p=50201',
    aclResourcesAccessLegacy: '/centreon/main.php?p=50202',
    resourceAccessRules: '/centreon/administration/resource-access/rules',
    accountParametersLegacy: '/centreon/main.php?p=50104&o=c',
    centreonUiParametersLegacy: '/centreon/main.php?p=50110&o=general',
    databasesPlatformStatusLegacy: '/centreon/main.php?p=50503',
    authenticationTokens: '/centreon/administration/api-token',
    contactsUsersLegacy: '/centreon/main.php?p=60301',
    contactGroupsLegacy: '/centreon/main.php?p=60302',
    contactTemplatesLegacy: '/centreon/main.php?p=60306',
    agentConfigurations: '/centreon/configuration/pollers/agent-configurations',
    additionalConfigurations: '/centreon/configuration/additional-connector-configurations',
    hostsTemplatesLegacy: '/centreon/main.php?p=60103',
    hostsLegacy: '/centreon/main.php?p=60101',
    hostCategoriesLegacy: '/centreon/main.php?p=60104',
    hostsDependenciesLegacy: '/centreon/main.php?p=60407',
    hostGroupsLegacy: '/centreon/main.php?p=60102',
    hostGroupsDependenciesLegacy: '/centreon/main.php?p=60408',
    authentication: '/centreon/administration/authentication',
    backupParametersLegacy: '/centreon/main.php?p=50165&o=backup',
    cloudNotifications: '/centreon/configuration/notifications',
    timePeriodsLegacy: '/centreon/main.php?p=60304',
    commandsChecksLegacy: '/centreon/main.php?p=60801&type=2',
    commandsMiscellaneousLegacy: '/centreon/main.php?p=60803&type=3',
    commandsConnectorsLegacy: '/centreon/main.php?p=60806',
    commandsDiscoveryLegacy: '/centreon/main.php?p=60807&type=4',
    commandsNotificationLegacy: '/centreon/main.php?p=60802&type=1',
    servicesTemplatesLegacy: '/centreon/main.php?p=60206',
    servicesByHostLegacy: '/centreon/main.php?p=60201',
    servicesCategoriesLegacy: '/centreon/main.php?p=60209',
    servicesGroupsLegacy: '/centreon/main.php?p=60203',
    servicesDependenciesLegacy: '/centreon/main.php?p=60409',
    serviceGroupsDependenciesLegacy: '/centreon/main.php?p=60410',
    servicesByHostGroupsLegacy: '/centreon/main.php?p=60202',
    metaServicesLegacy: '/centreon/main.php?p=60204',
    metaServicesDependenciesLegacy: '/centreon/main.php?p=60411',
    servicesGridLegacy: '/centreon/main.php?p=20204&o=svcOV_pb',
    escalationsLegacy: '/centreon/main.php?p=60401',
    pollersLegacy: '/centreon/main.php?p=60901',
    centreonUiLegacy: '/centreon/main.php?p=50110&o=general',
    snmpTrapsLegacy: '/centreon/main.php?p=61701',
    hostsKnowledgeBaseLegacy: '/centreon/main.php?p=61001',
    servicesKnowledgeBaseLegacy: '/centreon/main.php?p=61002',
    knowledgeBaseLegacy: '/centreon/main.php?p=50133&o=knowledgeBase',
    ldapsLegacy: '/centreon/main.php?p=50113&o=ldap',
    logsLegacy: '/centreon/main.php?p=508',
    snmpTrapsGroupsLegacy: '/centreon/main.php?p=61705',
    snmpTrapsManufacturerLegacy: '/centreon/main.php?p=61702',
    snmpTrapsGenerateLegacy: '/centreon/main.php?p=61704'
  },
  monitoring: {
    resourcesStatus: '/centreon/monitoring/resources',
    customViewsLegacy: '/centreon/main.php?p=103',
    dashboards: '/centreon/home/dashboards',
    dashboardsLibrary: '/centreon/home/dashboards/library',
    downtimesLegacy: '/centreon/main.php?p=21001',
    performancesGraphsLegacy: '/centreon/main.php?p=20401',
    virtualMetricsLegacy: '/centreon/main.php?p=20408',
    statusDetailsServicesLegacy: '/centreon/main.php?p=20201'
  }
};

==> centreon-web-24.10.21.tar.gz: centreon-web-24.10.21/tests/e2e/fixtures/shared/constants/pages.ts <==
export const PAGES = {
  configuration: {
    login: '/centreon/login',
    install: '/centreon/install/install.php',
    aclAccessGroupsLegacy: '/centreon/main.php?p=50203',
    aclActionsAccessLegacy: '/centreon/main.php?p=50204',
    aclMenusAccessLegacy: '/centreon/main.php?p=50201',
    aclResourcesAccessLegacy: '/centreon/main.php?p=50202',
    resourceAccessRules: '/centreon/administration/resource-access/rules',
    accountParametersLegacy: '/centreon/main.php?p=50104&o=c',
    centreonUiParametersLegacy: '/centreon/main.php?p=50110&o=general',
    databasesPlatformStatusLegacy: '/centreon/main.php?p=50503',
    authenticationTokens: '/centreon/administration/authentication-token',
    contactsUsersLegacy: '/centreon/main.php?p=60301',
    contactGroupsLegacy: '/centreon/main.php?p=60302',
    contactTemplatesLegacy: '/centreon/main.php?p=60306',
    agentConfigurations: '/centreon/configuration/pollers/agent-configurations',
    additionalConfigurations: '/centreon/configuration/additional-connector-configurations',
    hostsTemplatesLegacy: '/centreon/main.php?p=60103',
    hostsLegacy: '/centreon/main.php?p=60101',
    hostCategoriesLegacy: '/centreon/main.php?p=60104',
    hostsDependenciesLegacy: '/centreon/main.php?p=60407',
    hostGroupsLegacy: '/centreon/main.php?p=60102',
    hostGroupsDependenciesLegacy: '/centreon/main.php?p=60408',
    authentication: '/centreon/administration/authentication',
    backupParametersLegacy: '/centreon/main.php?p=50165&o=backup',
    cloudNotifications: '/centreon/configuration/notifications',
    timePeriodsLegacy: '/centreon/main.php?p=60304',
    commandsChecksLegacy: '/centreon/main.php?p=60801&type=2',
    commandsMiscellaneousLegacy: '/centreon/main.php?p=60803&type=3',
    commandsConnectorsLegacy: '/centreon/main.php?p=60806',
    commandsDiscoveryLegacy: '/centreon/main.php?p=60807&type=4',
    commandsNotificationLegacy: '/centreon/main.php?p=60802&type=1',
    servicesTemplatesLegacy: '/centreon/main.php?p=60206',
    servicesByHostLegacy: '/centreon/main.php?p=60201',
    servicesCategoriesLegacy: '/centreon/main.php?p=60209',
    servicesGroupsLegacy: '/centreon/main.php?p=60203',
    servicesDependenciesLegacy: '/centreon/main.php?p=60409',
    serviceGroupsDependenciesLegacy: '/centreon/main.php?p=60410',
    servicesByHostGroupsLegacy: '/centreon/main.php?p=60202',
    metaServicesLegacy: '/centreon/main.php?p=60204',
    metaServicesDependenciesLegacy: '/centreon/main.php?p=60411',
    servicesGridLegacy: '/centreon/main.php?p=20204&o=svcOV_pb',
    escalationsLegacy: '/centreon/main.php?p=60401',
    pollersLegacy: '/centreon/main.php?p=60901',
    centreonUiLegacy: '/centreon/main.php?p=50110&o=general',
    snmpTrapsLegacy: '/centreon/main.php?p=61701',
    hostsKnowledgeBaseLegacy: '/centreon/main.php?p=61001',
    servicesKnowledgeBaseLegacy: '/centreon/main.php?p=61002',
    knowledgeBaseLegacy: '/centreon/main.php?p=50133&o=knowledgeBase',
    ldapsLegacy: '/centreon/main.php?p=50113&o=ldap',
    logsLegacy: '/centreon/main.php?p=508',
    snmpTrapsGroupsLegacy: '/centreon/main.php?p=61705',
    snmpTrapsManufacturerLegacy: '/centreon/main.php?p=61702',
    snmpTrapsGenerateLegacy: '/centreon/main.php?p=61704'
  },
  monitoring: {
    resourcesStatus: '/centreon/monitoring/resources',
    customViewsLegacy: '/centreon/main.php?p=103',
    dashboards: '/centreon/home/dashboards',
    dashboardsLibrary: '/centreon/home/dashboards/library',
    downtimesLegacy: '/centreon/main.php?p=21001',
    performancesGraphsLegacy: '/centreon/main.php?p=20401',
    virtualMetricsLegacy: '/centreon/main.php?p=20408',
    statusDetailsServicesLegacy: '/centreon/main.php?p=20201'
  }
};
